# catchmeup

Get a quick summary of recent work and current status to help you jump back into the project.

## Prompt

Hey, I'm just getting back into this repo. Can you catch me up on where we are? Please:

1. Check the last 5 commits on the current branch and give me a quick summary of what was being worked on
2. Look at any staged or unstaged changes and tell me what's currently in flight
3. Try to identify if this work relates to any tickets or issues (look for patterns like #123, JIRA-456, etc. in commit messages)
4. Give me a conversational summary that helps me understand where I left off

Keep it personal and focused - just what I need to get back into the flow. Thanks!
